==> trade-center-api-2.0.8-xt-20180717.055113-1-sources.jar: cn/com/duiba/order/center/api/paramquery/OrdersAppSearchQuery.java <==
package cn.com.duiba.order.center.api.paramquery;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by yansen on 17/8/17.
 */
public class OrdersAppSearchQuery  implements Serializable{

    private static final long serialVersionUID = -2471840020624126786L;

    private Long appId;
    private Date startDate;
    private Date endDate;
    private String itemType;
    private String bizParams;
    private Long consumerId;
    private String orderType;
    private String orderId;
    private String namelike;
    private String exchangeStatus;
    private Integer offset=0;
    private Integer max=20;
    private String tableName;

    private String orderTimeType;

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }

    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }

    public String getItemType() {
        return itemType;
    }

    public void setItemType(String itemType) {
        this.itemType = itemType;
    }

    public String getBizParams() {
        return bizParams;
    }

    public void setBizParams(String bizParams) {
        this.bizParams = bizParams;
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    public String getOrderType() {
        return orderType;
    }

    public void setOrderType(String orderType) {
        this.orderType = orderType;
    }

    public String getOrderId() {
        return orderId;
    }

    public void setOrderId(String orderId) {
        this.orderId = orderId;
    }

    public String getNamelike() {
        return namelike;
    }

    public void setNamelike(String namelike) {
        this.namelike = namelike;
    }

    public String getExchangeStatus() {
        return exchangeStatus;
    }

    public void setExchangeStatus(String exchangeStatus) {
        this.exchangeStatus = exchangeStatus;
    }

    public Integer getOffset() {
        return offset;
    }

    public void setOffset(Integer offset) {
        this.offset = offset;
    }

    public Integer getMax() {
        return max;
    }

    public void setMax(Integer max) {
        this.max = max;
    }

    public String getTableName() {
        return tableName;
    }

    public void setTableName(String tableName) {
        this.tableName = tableName;
    }

    public String getOrderTimeType() {
        return orderTimeType;
    }

    public void setOrderTimeType(String orderTimeType) {
        this.orderTimeType = orderTimeType;
    }
}

==> trade-center-api-2.3.77-xt21-20210929.125202-2-sources.jar: cn/com/duiba/order/center/api/paramquery/OrdersAppSearchQuery.java <==
package cn.com.duiba.order.center.api.paramquery;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by yansen on 17/8/17.
 */
public class OrdersAppSearchQuery  implements Serializable{

    private static final long serialVersionUID = -2471840020624126786L;

    private Long appId;
    private Date startDate;
    private Date endDate;
    private String itemType;
    private String bizParams;
    private Long consumerId;
    private String orderType;
    private String orderId;
    private String namelike;
    private String exchangeStatus;
    private Integer offset=0;
    private Integer max=20;
    private String tableName;
    private Boolean activityOrder;
    private Boolean supplierOrder;
    //默认降序，升序传ASC
    private String  sortByGmtCreate;
    //订单来源，普兑给0，活动给1
    private String  relationType;
    //新版订单状态，待付款（100），待审核（200），待发货（300），待收货（400），已收货（500），已失效(700)，已取消(800)，已完成(900)，异常（1000），失败（1100，兼容老数据）
    private Integer  statusInt	;

    public Integer getStatusInt() {
        return statusInt;
    }

    public void setStatusInt(Integer statusInt) {
        this.statusInt = statusInt;
    }

    public String getSortByGmtCreate() {
        return sortByGmtCreate;
    }

    public void setSortByGmtCreate(String sortByGmtCreate) {
        this.sortByGmtCreate = sortByGmtCreate;
    }

    public String getRelationType() {
        return relationType;
    }

    public void setRelationType(String relationType) {
        this.relationType = relationType;
    }

    public Boolean getSupplierOrder() {
        return supplierOrder;
    }

    public void setSupplierOrder(Boolean supplierOrder) {
        this.supplierOrder = supplierOrder;
    }

    public Boolean getActivityOrder() {
        return activityOrder;
    }

    public void setActivityOrder(Boolean activityOrder) {
        this.activityOrder = activityOrder;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }

    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }

    public String getItemType() {
        return itemType;
    }

    public void setItemType(String itemType) {
        this.itemType = itemType;
    }

    public String getBizParams() {
        return bizParams;
    }

    public void setBizParams(String bizParams) {
        this.bizParams = bizParams;
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    public String getOrderType() {
        return orderType;
    }

    public void setOrderType(String orderType) {
        this.orderType = orderType;
    }

    public String getOrderId() {
        return orderId;
    }

    public void setOrderId(String orderId) {
        this.orderId = orderId;
    }

    public String getNamelike() {
        return namelike;
    }

    public void setNamelike(String namelike) {
        this.namelike = namelike;
    }

    public String getExchangeStatus() {
        return exchangeStatus;
    }

    public void setExchangeStatus(String exchangeStatus) {
        this.exchangeStatus = exchangeStatus;
    }

    public Integer getOffset() {
        return offset;
    }

    public void setOffset(Integer offset) {
        this.offset = offset;
    }

    public Integer getMax() {
        return max;
    }

    public void setMax(Integer max) {
        this.max = max;
    }

    public String getTableName() {
        return tableName;
    }

    public void setTableName(String tableName) {
        this.tableName = tableName;
    }
}
